import tw2.core as twc
from tw2.core.resources import encoder

import tw2.jqplugins.ui
import tw2.jqplugins.ui.base

import base

class MenuWidget(tw2.jqplugins.ui.base.JQueryUIWidget, twc.DisplayOnlyWidget):
    """ Slidey menu that I made just for you!

    This is *quite* alpha still.  Please play with it and enhance it if you
    like.

    options::

        - width:  -- the width of the menu.

    """

    resources = [
        tw2.jquery.jquery_js,
        tw2.jqplugins.ui.jquery_ui_js,
        tw2.jqplugins.ui.jquery_ui_css,
        base.slidey_js,
        base.slidey_css,
    ]

    template = "mako:tw2.slideymenu.templates.menu"

    items = twc.Param('A recursive dictionary of menu entries', default=[])
    label = twc.Param('Label for the menu-show button', default='Menu')
    options = twc.Param('Options.', default={})

    def prepare(self):
        super(MenuWidget, self).prepare()
        self._options = encoder.encode(self.options)



"""
Here you can create samples of your widgets by providing default parameters,
inserting them in a container widget, mixing them with other widgets, etc...
These samples will appear in the WidgetBrowser

See http://toscawidgets.org/documentation/WidgetBrowser for more information
"""

from widgets import MenuWidget


class DemoMenuWidget(MenuWidget):
    items = [
        {
            'label': 'An item',
            'href': "javascript:alert('clicked -- yes');",
        }, {
            'label': 'Another item',
            'href': "javascript:alert('clicked -- yes');",
        }, {
            'label': 'An item with no href',
        }
    ]

    label = 'A slidey menu'
    options = {
        'width': '500px'
    }



""" TW2 fancy slidey menu that I made just for you!

Slideymenu is best demonstrated by its use in `narcissus
<http://narcissus.rc.rit.edu>`_.  Definitely check it out.

You can also see it in the `tw2 WidgetBrowser
<http://tw2-demos.threebean.org/module?module=tw2.slideymenu>`_ although it
doesn't do it justice.

Get the source from http://github.com/toscawidgets/tw2.slideymenu
"""

from widgets import *




# TW2 proper imports
import tw2.core as twc

slidey_js = twc.JSLink(modname=__name__, filename='static/js/slidey.js')
slidey_css = twc.CSSLink(modname=__name__, filename='static/css/slidey.css')

__all__ = ['slidey_js']
